/*
    upad - A program for debugging, and uploading code to embedded devices.
    Copyright (C) 2016, 2019 John Darrington

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation, Inc.,
    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*/
#ifndef _COMMANDS_H_
#define _COMMANDS_H_

enum cmd
  {
    CMD_ACK,
    CMD_NACK,
    CMD_POLL,
    CMD_ECHO,
    CMD_BKDM,
    CMD_SYNC,
    CMD_BULK_ERASE,
    CMD_EEPROM,
    CMD_PFLASH,
    CMD_RESET,
    CMD_READ_BDCCSR,
    CMD_READ_MEM,
    CMD_READ_ALL_REGS,
    CMD_READ_REG,
    CMD_GO,
    CMD_BACKGROUND,
    CMD_STEP,
    CMD_WRITE_MEM,
    CMD_WRITE_BDCCSR,
    CMD_WRITE_REGS,
    CMD_MD5_CHECK,
    CMD_ERASE_EEPROM_SECTOR,
    CMD_ERASE_PFLASH_SECTOR,
    CMD_AUTOCONNECT,
    n_CMDS
  };

#endif


/* Local Variables:  */
/* mode: c           */
/* c-style: "gnu"    */
/* End:              */
